## START: Set by rpmautospec
## (rpmautospec version 0.6.5)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 4;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

# This package needs to be run as root and may
# run for a long time, thus we build with full
# hardening. This flags is enabled by default
# on recent Fedora releases, but we need to
# specify it for EPEL <= 7 explicitly.
%global _hardened_build 1


Name:           timeshift
Version:        22.11.2
Release:        %autorelease
Summary:        System restore tool for Linux

License:        GPLv3+ or LGPLv3+
URL:            https://github.com/linuxmint/timeshift
Source0:        %{url}/archive/refs/tags/%{version}.tar.gz

BuildRequires:  make
BuildRequires:  desktop-file-utils
BuildRequires:  gettext
BuildRequires:  libappstream-glib
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(vte-2.91)
BuildRequires:  vala

Requires:       cronie
Requires:       hicolor-icon-theme
Requires:       polkit
Requires:       psmisc
Requires:       rsync

# For btrfs systems
Recommends:     btrfs-progs

%description
Timeshift for Linux is an application that provides functionality similar to
the System Restore feature in Windows and the Time Machine tool in Mac OS.
Timeshift protects your system by taking incremental snapshots of the file
system at regular intervals. These snapshots can be restored at a later date
to undo all changes to the system.

In RSYNC mode, snapshots are taken using rsync and hard-links. Common files
are shared between snapshots which saves disk space. Each snapshot is a full
system backup that can be browsed with a file manager.

In BTRFS mode, snapshots are taken using the in-built features of the BTRFS
filesystem. BTRFS snapshots are supported only on BTRFS systems having an
Ubuntu-type subvolume layout (with @ and @home subvolumes).


%prep
%autosetup -n %{name}-%{version} -p1
sed -i -e 's@--thread @@g' src/makefile
sed -i -e 's@--Xcc="-O3" @@g' src/makefile
sed -i '/${app_name}-uninstall/d' src/makefile

%build
for flag in %{optflags} %{?__global_ldflags}; do
  VALAFLAGS="$VALAFLAGS -X $flag"
done

# Inject Fedora compiler flags and the debug option to valac.
# Just dump the c-sources.
sed -i "s|^[\t ]*valac|& --ccode --save-temps -g $VALAFLAGS|" src/makefile
%make_build

# Move generated c-sources into flat tree so it can be picked
# up for -debugsource.
for f in `find src/ -type f -name '*.c'`; do
  mv -f $f src/
done

# Inject Fedora compiler flags and the debug option to valac
# Build the binaries.
sed -i "s|valac --ccode|valac|" src/makefile
%make_build


%install
%make_install
# Remove duplicate
rm -rf %{buildroot}%{_datadir}/appdata

%find_lang %{name}


%check
appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/*.appdata.xml
desktop-file-validate %{buildroot}%{_datadir}/applications/%{name}-gtk.desktop


%if 0%{?rhel} && 0%{?rhel} <= 7
%post
/bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :

%postun
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi

%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
%endif


%files -f %{name}.lang
%license COPYING LICENSE.md
%doc AUTHORS README.md
%{_bindir}/*
%{_datadir}/metainfo/*.appdata.xml
%{_datadir}/applications/*
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/polkit-1/actions/*.policy
%{_datadir}/%{name}
%{_mandir}/man1/%{name}.1*
%ghost %attr(644, root, root) %{_sysconfdir}/cron.d/%{name}-boot
%ghost %attr(644, root, root) %{_sysconfdir}/cron.d/%{name}-hourly
%ghost %attr(664, root, root) %{_sysconfdir}/%{name}.json
%config %{_sysconfdir}/%{name}/default.json



%changelog
## START: Generated by rpmautospec
* Sat Jul 20 2024 Fedora Release Engineering <releng@fedoraproject.org> - 22.11.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Sat Jan 27 2024 Fedora Release Engineering <releng@fedoraproject.org> - 22.11.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Sat Jul 22 2023 Fedora Release Engineering <releng@fedoraproject.org> - 22.11.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Thu Jan 19 2023 Onuralp SEZER <thunderbirdtr@fedoraproject.org> - 22.11.2-1
- update to version 22.11.2 and release and changelog spec files changes

* Sun Aug 21 2022 Ivan Vorstanenko <ivanvorstanenko@proton.me> - 22.06.5-1
- Update timeshift.spec

* Sat Jul 23 2022 Fedora Release Engineering <releng@fedoraproject.org> - 21.09.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Tue Mar 15 2022 Onuralp SEZER <thunderbirdtr@fedoraproject.org> - 21.09.1-2
- remove old patch

* Tue Mar 15 2022 Onuralp SEZER <thunderbirdtr@fedoraproject.org> - 21.09.1-1
- Update to 21.09.1

* Sat Jan 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 20.03-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Fri Jul 23 2021 Fedora Release Engineering <releng@fedoraproject.org> - 20.03-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 20.03-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Fri Jan 08 2021 Tom Stellard <tstellar@redhat.com> - 20.03-4
- Add BuildRequires: make

* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 20.03-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Sun Mar 15 2020 Samuel Rakitničan <samuel.rakitnican@gmail.com> - 20.03-2
- Add the translation newline fix patch

* Sun Mar 15 2020 Samuel Rakitničan <samuel.rakitnican@gmail.com> - 20.03-1
- Update to 20.03

* Fri Jan 31 2020 Fedora Release Engineering <releng@fedoraproject.org> - 19.08.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Sat Sep 28 2019 Richard Shaw <hobbes1069@gmail.com> - 19.08.1-1
- Update to 19.08.1. Add patch to deal with abstract class compile error.

* Sat Mar 09 2019 Samuel Rakitničan <samuel.rakitnican@gmail.com> - 19.01-1
- Update to 19.01

* Sun Mar 03 2019 Leigh Scott <leigh123linux@googlemail.com> - 18.6.1-4
- Fix build errors with newer vala, remove --threads from makefile

* Sun Feb 03 2019 Fedora Release Engineering <releng@fedoraproject.org> - 18.6.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 18.6.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Sun Jun 24 2018 Samuel Rakitničan <samuel.rakitnican@gmail.com> - 18.6.1-1
- Update to 18.6.1

* Sun Jun 24 2018 Samuel Rakitničan <samuel.rakitnican@gmail.com> - 18.4-1
- Update to 18.4
- Add runtime dependency on psmisc
- Update sed expression to avoid false matches

* Sun Feb 18 2018 Samuel Rakitničan <samuel.rakitnican@gmail.com> - 18.2-2
- Remove rpath workaround

* Sun Feb 18 2018 Samuel Rakitničan <samuel.rakitnican@gmail.com> - 18.2-1
- Update to 18.2

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 18.1.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Sun Jan 28 2018 Björn Esser <besser82@fedoraproject.org> - 18.1.1-4
- Generate useful -debugsource package

* Sun Jan 28 2018 Björn Esser <besser82@fedoraproject.org> - 18.1.1-3
- Properly apply system LDFLAGS and thus enable full hardening

* Fri Jan 26 2018 Samuel Rakitničan <samuel.rakitnican@gmail.com> - 18.1.1-2
- Icon cache scriptlet for EPEL

* Fri Jan 26 2018 Samuel Rakitničan <samuel.rakitnican@gmail.com> - 18.1.1-1
- Initial import (#1534446)
## END: Generated by rpmautospec
